@@ -1,3 +1,4 @@
+from .auth import __THMAuth
 from .koth import __THMKoth
 from .leaderboard import __THMLeaderboard
 from .room import __THMRoom
@@ -6,14 +7,18 @@ from .team import __THMTeam
 from .user import __THMUser
 import requests
 
+from .vpn import __THMVpn
+
 
 class THM(
+    __THMAuth,
     __THMStats,
     __THMLeaderboard,
     __THMTeam,
     __THMUser,
     __THMKoth,
-    __THMRoom
+    __THMRoom,
+    __THMVpn
 ):
     """
     TryHackMe API Wrapper
@@ -28,7 +33,8 @@ class THM(
         """
 
         self.session = requests.Session()
+        self.authenticated = False
 
-        # if (credentials is not None) and (type(credentials) == dict):
-        #     if ('username' in credentials) and ('password' in credentials):
-        #         self.__login(credentials)
+        if (credentials is not None) and (type(credentials) == dict):
+            if ('username' in credentials) and ('password' in credentials):
+                self.login(credentials)
